@@ -1,7 +1,6 @@
 import json
 from typing import Dict, List
 
-from pylint.interfaces import IReporter
 from pylint.reporters.ureports.nodes import BaseLayout
 
 from .core import NewMessage, PythonTaReporter
@@ -34,21 +33,8 @@ class JSONReporter(PythonTaReporter):
             output.append(
                 {
                     "filename": k,
-                    "msgs": [
-                        {**msg._replace(node=None)._asdict(), **self._snippet_endings(msg)}
-                        for msg in msgs
-                    ],
+                    "msgs": [msg.to_dict() for msg in msgs],
                 }
             )
 
         self.writeln(json.dumps(output, indent=4))
-
-    def _snippet_endings(self, msg: NewMessage) -> Dict[str, int]:
-        """Return a dictionary containing the index of the last line and the index of the last column of the
-        error reported by the message in msg.
-        """
-        if msg.node is None:
-            line_end, column_end = msg.line, len(self.source_lines[msg.line - 1])
-        else:
-            line_end, column_end = msg.node.end_lineno, msg.node.end_col_offset
-        return {"line_end": line_end, "column_end": column_end}
